@@ -273,10 +273,11 @@ class moduleVisitor(ASTVisitor):
 
         # determine base classes
         for cl in self.classes.values():
-            for base in cl.node.bases: # XXX getattr
-                ancestor = lookupclass(base, getmv())
-                cl.bases.append(ancestor)
-                ancestor.children.append(cl)
+            for base in cl.node.bases:
+                if not (isinstance(base, Name) and base.name == 'object'):
+                    ancestor = lookupclass(base, getmv())
+                    cl.bases.append(ancestor)
+                    ancestor.children.append(cl)
 
         # for each base class, duplicate methods
         for cl in self.classes.values():
@@ -1272,7 +1273,7 @@ class moduleVisitor(ASTVisitor):
             inode(arg).callfuncs.append(node) # this one too
 
         # --- handle instantiation or call
-        constructor = lookupclass(node.node, self)
+        constructor = lookupclass(node.node, getmv())
         if constructor and (not isinstance(node.node, Name) or not lookupvar(node.node.name, func)):
             self.instance(node, constructor, func)
             inode(node).callfuncs.append(node) # XXX see above, investigate
@@ -1398,10 +1399,7 @@ class moduleVisitor(ASTVisitor):
         self.instance(node, defclass(map[type(node.value)]), func)
 
     def fncl_passing(self, node, newnode, func):
-        mv = self
-        if isinstance(func, function) and func.inherited_from: 
-            mv = func.inherited_from.mv # XXX XXX XXX generalize XXX XXX XXX
-        lfunc, lclass = lookupfunc(node, mv), lookupclass(node, mv)
+        lfunc, lclass = lookupfunc(node, getmv()), lookupclass(node, getmv())
         if lfunc:
             if lfunc.mv.module.builtin:
                 lfunc = self.builtinwrapper(node, func)
