@@ -135,6 +135,9 @@ class float_:
     def __pow__(self, b):
         return b.__with_float__()
 
+    def is_integer(self):
+        return True
+
     def __neg__(self):
         return 1.0
     def __pos__(self):
@@ -178,16 +181,25 @@ class pyiter:
     def __with_int__(self):
         return self
 
+    def __contains__(self, x):
+        x == self.unit
+        return True
+
 class pyseq(pyiter):
     pass
 
 class list(pyseq):
     def append(self, u):
         self.unit = u
+
     def index(self, u, s=0, e=0):
+        u == self.unit
         return 1
     def count(self, u):
+        u == self.unit
         return 1
+    def remove(self, u):
+        u == self.unit
 
     def __getitem__(self, i):
         return self.unit
@@ -221,15 +233,14 @@ class list(pyseq):
         return ''
     def __str__(self):
         return self.__repr__()
+
     def extend(self, other):
         self.unit = other.unit
+    def insert(self, i, u):
+        self.unit = u
 
     def pop(self, m=0):
         return self.unit
-    def remove(self, u):
-        pass
-    def insert(self, i, u):
-        self.unit = u
 
     def reverse(self):
         pass
@@ -513,6 +524,19 @@ class pyset(pyiter):
     def __xor__(self, b):
         return self
 
+    def __ior__(self, b):
+        self.__setunit__(iter(b).next())
+        return self
+    def __iand__(self, b):
+        self.__setunit__(iter(b).next())
+        return self
+    def __ixor__(self, b):
+        self.__setunit__(iter(b).next())
+        return self
+    def __isub__(self, b):
+        self.__setunit__(iter(b).next())
+        return self
+
     def union(self, *b):
         return self
         return set(b)
@@ -535,8 +559,6 @@ class frozenset(pyset):
 class set(pyset):
     def add(self, u):
         self.__setunit__(u)
-    def __isub__(self, b):
-        return self
     def discard(self, u):
         pass
     def remove(self, u):
